"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.In = void 0;
const core_1 = require("@tsed/core");
const JsonEntityStore_1 = require("../../domain/JsonEntityStore");
const JsonParameter_1 = require("../../domain/JsonParameter");
const JsonSchema_1 = require("../../domain/JsonSchema");
/**
 * Add a input parameter.
 *
 * ::: warning
 * Don't use decorator with Ts.ED application to decorate parameters. Use @@BodyParams@@, @@PathParams@@, etc... instead.
 * But you can use this decorator on Method, to add extra in parameters like Authorization header.
 *
 * ```typescript
 * @Controller("/")
 * class MyController {
 *    @Get("/")
 *    @In("header").Type(String).Name("Authorization").Required()
 *    method() {
 *    }
 *  }
 * ```
 * :::
 *
 * @param inType
 * @decorator
 * @swagger
 * @schema
 * @input
 * @operation
 */
function In(inType) {
    const jsonParameter = new JsonParameter_1.JsonParameter();
    const schema = {};
    const decorator = (target, propertyKey, index) => {
        const store = JsonEntityStore_1.JsonEntityStore.from(target, propertyKey, index);
        switch (store.decoratorType) {
            case core_1.DecoratorTypes.PARAM:
                store.parameter.in(inType);
                break;
            case core_1.DecoratorTypes.METHOD:
                jsonParameter.in(inType);
                store.operation.addParameter(-1, jsonParameter);
                jsonParameter.schema(JsonSchema_1.JsonSchema.from(schema));
                break;
            case core_1.DecoratorTypes.CLASS:
                (0, core_1.decorateMethodsOf)(target, decorator);
                break;
            default:
                throw new core_1.UnsupportedDecoratorType(In, [target, propertyKey, index]);
        }
    };
    decorator.Type = (type) => {
        schema.type = type;
        return decorator;
    };
    decorator.Name = (name) => {
        jsonParameter.name(name);
        return decorator;
    };
    decorator.Description = (description) => {
        jsonParameter.description(description);
        return decorator;
    };
    decorator.Required = (required = true) => {
        jsonParameter.required(required);
        return decorator;
    };
    decorator.Pattern = (pattern) => {
        return decorator.Schema({ pattern: pattern.toString() });
    };
    decorator.Schema = (_schema) => {
        Object.assign(schema, _schema);
        return decorator;
    };
    return decorator;
}
exports.In = In;
//# sourceMappingURL=in.js.map